You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@geode.apache.org by zh...@apache.org on 2018/04/24 22:09:11 UTC

[geode] branch feature/GEODE-5138 updated (abdfcf9 -> 20f8745)

This is an automated email from the ASF dual-hosted git repository.

zhouxj pushed a change to branch feature/GEODE-5138
in repository https://gitbox.apache.org/repos/asf/geode.git.


 discard abdfcf9  GEODE-5138: rename the gateway sender stats to a better name
     add 0b7550f  Remove bookbinder lock from geode-book Gemfile
     add e26889d  GEODE-4647 Document eventSecondaryQueueSize statistic (#1831)
     add d4b02cb  GEODE-5129 Amend DistributedTestRule to honor the vmCount parameter when < 4 hosts
     add 9145fa3  GEODE-925: Replaced all Wait.pause with Awaitility. Replaced all ThreadUtils.join with an Awaitility. General code and lambda clean up Modify test to use test rules remove TODO from test
     new 20f8745  GEODE-5138: rename the gateway sender stats to a better name

This update added new revisions after undoing existing revisions.
That is to say, some revisions that were in the old version of the
branch are not in the new version.  This situation occurs
when a user --force pushes a change and generates a repository
containing something like this:

 * -- * -- B -- O -- O -- O   (abdfcf9)
            \
             N -- N -- N   refs/heads/feature/GEODE-5138 (20f8745)

You should already have received notification emails for all of the O
revisions, and so the following emails describe only the N revisions
from the common base, B.

Any revisions marked "omit" are not gone; other references still
refer to them.  Any revisions marked "discard" are gone forever.

The 1 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.


Summary of changes:
 geode-book/Gemfile                                 |   2 +-
 geode-book/Gemfile.lock                            |   8 +-
 .../dunit/QueryDataInconsistencyDUnitTest.java     | 745 +++++++++------------
 .../dunit/rules/AbstractDistributedTestRule.java   |   2 +-
 geode-docs/reference/statistics_list.html.md.erb   |   1 +
 5 files changed, 331 insertions(+), 427 deletions(-)

-- 
To stop receiving notification emails like this one, please contact
zhouxj@apache.org.

[geode] 01/01: GEODE-5138: rename the gateway sender stats to a better name

Posted by zh...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

zhouxj pushed a commit to branch feature/GEODE-5138
in repository https://gitbox.apache.org/repos/asf/geode.git

commit 20f8745e47bb3520150153087be01b9f5a654a3b
Author: zhouxh <gz...@pivotal.io>
AuthorDate: Tue Apr 24 15:07:08 2018 -0700

    GEODE-5138: rename the gateway sender stats to a better name
---
 .../asyncqueue/internal/AsyncEventQueueStats.java  |  9 ++++----
 .../wan/AbstractGatewaySenderEventProcessor.java   |  2 +-
 .../internal/cache/wan/GatewaySenderStats.java     | 25 +++++++++++-----------
 .../bean/stats/AsyncEventQueueStatsJUnitTest.java  |  2 +-
 .../geode/internal/cache/wan/WANTestBase.java      |  6 +++---
 .../ParallelGatewaySenderOperationsDUnitTest.java  |  8 +++----
 6 files changed, 27 insertions(+), 25 deletions(-)

diff --git a/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/AsyncEventQueueStats.java b/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/AsyncEventQueueStats.java
index 963b828..2f317cf 100644
--- a/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/AsyncEventQueueStats.java
+++ b/geode-core/src/main/java/org/apache/geode/cache/asyncqueue/internal/AsyncEventQueueStats.java
@@ -92,8 +92,9 @@ public class AsyncEventQueueStats extends GatewaySenderStats {
             f.createIntGauge(CONFLATION_INDEXES_MAP_SIZE,
                 "Current number of entries in the conflation indexes map.", "events"),
             f.createIntCounter(NOT_QUEUED_EVENTS, "Number of events not added to queue.", "events"),
-            f.createIntCounter(NOT_QUEUED_EVENTS_AT_YET_RUNNING_PRIMARY_SENDER,
-                "Number of events not added to primary queue due to sender yet running.", "events"),
+            f.createIntCounter(EVENTS_DROPPED_DUE_TO_PRIMARY_SENDER_NOT_RUNNING,
+                "Number of events dropped because the primary gateway sender is not running.",
+                "events"),
             f.createIntCounter(EVENTS_FILTERED,
                 "Number of events filtered through GatewayEventFilter.", "events"),
             f.createIntCounter(LOAD_BALANCES_COMPLETED, "Number of load balances completed",
@@ -131,8 +132,8 @@ public class AsyncEventQueueStats extends GatewaySenderStats {
     unprocessedTokenMapSizeId = type.nameToId(UNPROCESSED_TOKEN_MAP_SIZE);
     conflationIndexesMapSizeId = type.nameToId(CONFLATION_INDEXES_MAP_SIZE);
     notQueuedEventsId = type.nameToId(NOT_QUEUED_EVENTS);
-    notQueuedEventsAtYetRunningPrimarySenderId =
-        type.nameToId(NOT_QUEUED_EVENTS_AT_YET_RUNNING_PRIMARY_SENDER);
+    eventsDroppedDueToPrimarySenderNotRunningId =
+        type.nameToId(EVENTS_DROPPED_DUE_TO_PRIMARY_SENDER_NOT_RUNNING);
     eventsFilteredId = type.nameToId(EVENTS_FILTERED);
     eventsConflatedFromBatchesId = type.nameToId(EVENTS_CONFLATED_FROM_BATCHES);
     loadBalancesCompletedId = type.nameToId(LOAD_BALANCES_COMPLETED);
diff --git a/geode-core/src/main/java/org/apache/geode/internal/cache/wan/AbstractGatewaySenderEventProcessor.java b/geode-core/src/main/java/org/apache/geode/internal/cache/wan/AbstractGatewaySenderEventProcessor.java
index cdf6125..cdbf056 100644
--- a/geode-core/src/main/java/org/apache/geode/internal/cache/wan/AbstractGatewaySenderEventProcessor.java
+++ b/geode-core/src/main/java/org/apache/geode/internal/cache/wan/AbstractGatewaySenderEventProcessor.java
@@ -301,7 +301,7 @@ public abstract class AbstractGatewaySenderEventProcessor extends Thread {
       boolean isPrimary = prQ.getRegionAdvisor().getBucketAdvisor(bucketId).isPrimary();
       if (isPrimary) {
         pgsq.sendQueueRemovalMesssageForDroppedEvent(prQ, bucketId, shadowKey);
-        this.sender.getStatistics().incEventsNotQueuedAtYetRunningPrimarySender();
+        this.sender.getStatistics().incEventsDroppedDueToPrimarySenderNotRunning();
         if (logger.isDebugEnabled()) {
           logger.debug("register dropped event for primary queue. BucketId is " + bucketId
               + ", shadowKey is " + shadowKey + ", prQ is " + prQ.getFullPath());
diff --git a/geode-core/src/test/java/org/apache/geode/management/bean/stats/AsyncEventQueueStatsJUnitTest.java b/geode-core/src/test/java/org/apache/geode/management/bean/stats/AsyncEventQueueStatsJUnitTest.java
index c475d4e..ec7e3fb 100644
--- a/geode-core/src/test/java/org/apache/geode/management/bean/stats/AsyncEventQueueStatsJUnitTest.java
+++ b/geode-core/src/test/java/org/apache/geode/management/bean/stats/AsyncEventQueueStatsJUnitTest.java
@@ -65,7 +65,7 @@ public class AsyncEventQueueStatsJUnitTest extends MBeanStatsTestCase {
       if (s.getName().equals("notQueuedEvent")) {
         notQueueEvents++;
       }
-      if (s.getName().equals("notQueuedEventAtYetRunningPrimarySender")) {
+      if (s.getName().equals("eventsDroppedDueToPrimarySenderNotRunning")) {
         notQueueToPrimary++;
       }
       if (s.getName().equals("eventsProcessedByPQRM")) {
diff --git a/geode-wan/src/test/java/org/apache/geode/internal/cache/wan/WANTestBase.java b/geode-wan/src/test/java/org/apache/geode/internal/cache/wan/WANTestBase.java
index f429919..aa9e776 100644
--- a/geode-wan/src/test/java/org/apache/geode/internal/cache/wan/WANTestBase.java
+++ b/geode-wan/src/test/java/org/apache/geode/internal/cache/wan/WANTestBase.java
@@ -1228,10 +1228,10 @@ public class WANTestBase extends DistributedTestCase {
     AbstractGatewaySender sender = (AbstractGatewaySender) cache.getGatewaySender(senderId);
     GatewaySenderStats statistics = sender.getStatistics();
     ArrayList<Integer> stats = new ArrayList<Integer>();
-    int eventNotQueued = statistics.getEventsNotQueuedAtYetRunningPrimarySender();
+    int eventNotQueued = statistics.getEventsDroppedDueToPrimarySenderNotRunning();
     if (eventNotQueued > 0) {
-      logger.info(
-          "Found " + eventNotQueued + " not queued events due to primary sender is yet running");
+      logger
+          .info("Found " + eventNotQueued + " evebts dropped due to primary sender is not running");
     }
     stats.add(eventNotQueued);
     stats.add(statistics.getEventsNotQueued());
diff --git a/geode-wan/src/test/java/org/apache/geode/internal/cache/wan/parallel/ParallelGatewaySenderOperationsDUnitTest.java b/geode-wan/src/test/java/org/apache/geode/internal/cache/wan/parallel/ParallelGatewaySenderOperationsDUnitTest.java
index f5b98b7..c6b570f 100644
--- a/geode-wan/src/test/java/org/apache/geode/internal/cache/wan/parallel/ParallelGatewaySenderOperationsDUnitTest.java
+++ b/geode-wan/src/test/java/org/apache/geode/internal/cache/wan/parallel/ParallelGatewaySenderOperationsDUnitTest.java
@@ -413,7 +413,7 @@ public class ParallelGatewaySenderOperationsDUnitTest extends WANTestBase {
     ArrayList<Integer> vm5List = null;
     ArrayList<Integer> vm6List = null;
     ArrayList<Integer> vm7List = null;
-    boolean foundDroppedAtYetStartedPrimarySender = false;
+    boolean foundEventsDroppedDueToPrimarySenderNotRunning = false;
     int count = 0;
 
     do {
@@ -433,11 +433,11 @@ public class ParallelGatewaySenderOperationsDUnitTest extends WANTestBase {
       vm7List =
           (ArrayList<Integer>) vm7.invoke(() -> WANTestBase.getSenderStatsForDroppedEvents("ln"));
       if (vm4List.get(0) + vm5List.get(0) + vm6List.get(0) + vm7List.get(0) > 0) {
-        foundDroppedAtYetStartedPrimarySender = true;
+        foundEventsDroppedDueToPrimarySenderNotRunning = true;
       }
       count++;
-    } while (foundDroppedAtYetStartedPrimarySender == false && count < 5);
-    assertThat(foundDroppedAtYetStartedPrimarySender);
+    } while (foundEventsDroppedDueToPrimarySenderNotRunning == false && count < 5);
+    assertThat(foundEventsDroppedDueToPrimarySenderNotRunning);
 
     // verify all the buckets on all the sender nodes are drained
     validateParallelSenderQueueAllBucketsDrained();

diff --git a/geode-core/src/main/java/org/apache/geode/internal/cache/wan/GatewaySenderStats.java b/geode-core/src/main/java/org/apache/geode/internal/cache/wan/GatewaySenderStats.java
index a9b4c21..220e0de 100644
--- a/geode-core/src/main/java/org/apache/geode/internal/cache/wan/GatewaySenderStats.java
+++ b/geode-core/src/main/java/org/apache/geode/internal/cache/wan/GatewaySenderStats.java
@@ -88,8 +88,8 @@ public class GatewaySenderStats {
 
   protected static final String EVENTS_FILTERED = "eventsFiltered";
   protected static final String NOT_QUEUED_EVENTS = "notQueuedEvent";
-  protected static final String NOT_QUEUED_EVENTS_AT_YET_RUNNING_PRIMARY_SENDER =
-      "notQueuedEventAtYetRunningPrimarySender";
+  protected static final String EVENTS_DROPPED_DUE_TO_PRIMARY_SENDER_NOT_RUNNING =
+      "eventsDroppedDueToPrimarySenderNotRunning";
 
   protected static final String LOAD_BALANCES_COMPLETED = "loadBalancesCompleted";
   protected static final String LOAD_BALANCES_IN_PROGRESS = "loadBalancesInProgress";
@@ -145,8 +145,8 @@ public class GatewaySenderStats {
   protected static int eventsFilteredId;
   /** Id of not queued events */
   protected static int notQueuedEventsId;
-  /** Id of not queued events due to the primary sender is yet running */
-  protected static int notQueuedEventsAtYetRunningPrimarySenderId;
+  /** Id of events dropped due to primary sender not running */
+  protected static int eventsDroppedDueToPrimarySenderNotRunningId;
   /** Id of events conflated in batch */
   protected static int eventsConflatedFromBatchesId;
   /** Id of load balances completed */
@@ -230,8 +230,9 @@ public class GatewaySenderStats {
             f.createIntGauge(CONFLATION_INDEXES_MAP_SIZE,
                 "Current number of entries in the conflation indexes map.", "events"),
             f.createIntCounter(NOT_QUEUED_EVENTS, "Number of events not added to queue.", "events"),
-            f.createIntCounter(NOT_QUEUED_EVENTS_AT_YET_RUNNING_PRIMARY_SENDER,
-                "Number of events not added to primary queue due to sender yet running.", "events"),
+            f.createIntCounter(EVENTS_DROPPED_DUE_TO_PRIMARY_SENDER_NOT_RUNNING,
+                "Number of events dropped because the primary gateway sender is not running.",
+                "events"),
             f.createIntCounter(EVENTS_FILTERED,
                 "Number of events filtered through GatewayEventFilter.", "events"),
             f.createIntCounter(LOAD_BALANCES_COMPLETED, "Number of load balances completed",
@@ -270,8 +271,8 @@ public class GatewaySenderStats {
     unprocessedTokenMapSizeId = type.nameToId(UNPROCESSED_TOKEN_MAP_SIZE);
     conflationIndexesMapSizeId = type.nameToId(CONFLATION_INDEXES_MAP_SIZE);
     notQueuedEventsId = type.nameToId(NOT_QUEUED_EVENTS);
-    notQueuedEventsAtYetRunningPrimarySenderId =
-        type.nameToId(NOT_QUEUED_EVENTS_AT_YET_RUNNING_PRIMARY_SENDER);
+    eventsDroppedDueToPrimarySenderNotRunningId =
+        type.nameToId(EVENTS_DROPPED_DUE_TO_PRIMARY_SENDER_NOT_RUNNING);
     eventsFilteredId = type.nameToId(EVENTS_FILTERED);
     eventsConflatedFromBatchesId = type.nameToId(EVENTS_CONFLATED_FROM_BATCHES);
     loadBalancesCompletedId = type.nameToId(LOAD_BALANCES_COMPLETED);
@@ -699,12 +700,12 @@ public class GatewaySenderStats {
     return this.stats.getInt(notQueuedEventsId);
   }
 
-  public void incEventsNotQueuedAtYetRunningPrimarySender() {
-    this.stats.incInt(notQueuedEventsAtYetRunningPrimarySenderId, 1);
+  public void incEventsDroppedDueToPrimarySenderNotRunning() {
+    this.stats.incInt(eventsDroppedDueToPrimarySenderNotRunningId, 1);
   }
 
-  public int getEventsNotQueuedAtYetRunningPrimarySender() {
-    return this.stats.getInt(notQueuedEventsAtYetRunningPrimarySenderId);
+  public int getEventsDroppedDueToPrimarySenderNotRunning() {
+    return this.stats.getInt(eventsDroppedDueToPrimarySenderNotRunningId);
   }
 
   public void incEventsFiltered() {
-- 
To stop receiving notification emails like this one, please contact
zhouxj@apache.org.